# Xircuits Component Library List


## Internal Library

These components will always be included in the Xircuits installation.

| Name     | Description                                                                                    |                                                                                                                                                            |
| -------- | ---------------------------------------------------------------------------------------------- | -------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| Learning | Deep learning related components using Tensorflow Keras.                                       | [Link](https://github.com/XpressAI/xircuits/tree/master/xai_components/xai_learning) |
| Pytorch  | Components that use Pytorch's ML library.                                                      | [Link](https://github.com/XpressAI/xircuits/tree/master/xai_components/xai_pytorch)   |
| Spark    | Components built using the Pyspark library. Run these components with the Xircuits Remote Run! | [Link](https://github.com/XpressAI/xircuits/tree/master/xai_components/xai_spark)       |
| Template | Great components for new learners and to experiment outputs.                                   | [Link](https://github.com/XpressAI/xircuits/tree/master/xai_components/xai_template) |
| Utils    | Commonly used components for day-to-day workflows.                                             | [Link](https://github.com/XpressAI/xircuits/tree/master/xai_components/xai_utils)       |


## External Library

Recognized additional component libraries that you can download using:

```
$ xircuits-components --sublib componentLibraryName
```

Don't forget to install their packages after fetching the library!

| Name       | Description                                                                                                                                          | Link                                                                               |
| ---------- | ---------------------------------------------------------------------------------------------------------------------------------------------------- | ---------------------------------------------------------------------------------- |
| Pycaret    | A component library built using Pycaret's API! Complete with examples for NLP, anomaly detection, classification, clustering, as well as regression. | [Link](https://github.com/XpressAI/xai-pycaret) |
| Modelstash | Coming Soon...                                                                                                                                       | Coming Soon...                                                                     |

Want your component library listed here? Just submit a PR to the Xircuits repository. For more information, refer to the [Xircuits component library documentation](https://xircuits.io/docs/technical-concepts/xircuits-component-library).